
  PRO COORD2D, NX, NY, XX, YY, xmin=XMIN, xmax=XMAX, ymin=YMIN, ymax=YMAX
; ========================================================================
; Create two 2D coordinate arrays XX and YY for direct evaluation of 
; analytical function on the coordintate grid. 
; 
; Input parameters: 
;     NX : number of elements in x direction (first dimension) 
;     NY : number of elements in y direction (second dimension) 
; 
; Keywords (optional input): 
;     XMIN : minimum of x range (default: 0.)
;     XMAX : maximum of x range (default: 1.)
;     YMIN : minimum of y range (default: 0.)
;     YMAX : maximum of y range (default: 1.)
;
; Output parameters: 
;     XX : 2D array of x coordinates 
;     YY : 2D array of y coordinates
; 
; JoV, 2/03
; ========================================================================

; Check keyword settings, assign default values if necessary.
; -----------------------------------------------------------
  if not keyword_set(XMIN) then XMIN=0.
  if not keyword_set(XMAX) then XMAX=1.
  if not keyword_set(YMIN) then YMIN=0.
  if not keyword_set(YMAX) then YMAX=1.

; Define 1D arrays for x and y coordinates.
; -----------------------------------------
  x = xmin + (xmax-xmin)*findgen(nx)/float(nx-1)
  y = ymin + (ymax-ymin)*findgen(ny)/float(ny-1)

; Define corresponding 1D arrays filled with ones. 
; ------------------------------------------------
  x1 = replicate(1.,nx)
  y1 = replicate(1.,ny)

; Create 2D arrays XX and YY.
; ---------------------------
  XX = x#y1
  YY = x1#y

  end
