
  FUNCTION BCURVED, R, noisel=NOISEL
; ===============================================================
; BCURVED simulates B field measurements in CURVED magnetic 
; field geometry to test effect of field line curvature 
; on gradient estimation.
;
; Model field is axially symmetric with respect to the z-axis 
; (magnetic field of a straight current wire).  
;
; R is expected to be a structure with 3 entries (.x .y .z) 
; and 4 sub-entries (.c1 .c2 .c3 .c4).  
; Output B is of the same structure.  
;
; Keyword NOISEL specifies noise level 
; (float, default: 0.)   
; 
; JoV, PeD, 2/04. 
; Modification history: 
;  
; ===============================================================

  if not keyword_set(NOISEL) then NOISEL=0.
  B = R

; Field parameters.
; -----------------
  B0=1.      ;... scale factor 

; Mimic random fluctuations.
; --------------------------
  nr = n_elements(R.x.c1)
  for i=0,3 do for j=0,2 do B.(j).(i) = NOISEL*B0*randomn(seed,nr)

; Cylindrical magnetic field.
; ---------------------------
  for i=0,3 do begin
    rmag2 = (R.x.(i))^2 + (R.y.(i))^2 
    B.x.(i) = B.x.(i) - B0 * R.y.(i) / rmag2
    B.y.(i) = B.y.(i) + B0 * R.x.(i) / rmag2
  endfor

  RETURN, B
  END
