
  FUNCTION BDIPOLE, R, noisel=NOISEL
; ===============================================================
; BDIPOLE simulates B field measurements in DIPOLE field 
; to test effects of field line convergence and curvature 
; on gradient estimation.
;
; The dipole moment is aligned with the z-axis 
; (should be OK if origin is not inside cluster tetrahedron). 
;
; R is expected to be a structure with 3 entries (.x .y .z) 
; and 4 sub-entries (.c1 .c2 .c3 .c4).  
; Output B is of the same structure.  
;
; Keyword NOISEL specifies noise level 
; (float, default: 0.)   
; 
; JoV, PeD, 2/04. 
; Modification history: 
;  
; ===============================================================

  if not keyword_set(NOISEL) then NOISEL=0.
  B = R

; Field parameters.
; -----------------
  B0=1.      ;... scale factor 

; Mimic random fluctuations.
; --------------------------
  nr = n_elements(R.x.c1)
  for i=0,3 do for j=0,2 do B.(j).(i) = NOISEL*B0*randomn(seed,nr)

; Dipole magnetic field.
; ----------------------
  for i=0,3 do begin
    rmag5 = ( (R.x.(i))^2 + (R.y.(i))^2 + (R.z.(i))^2 )^2.5
    B.x.(i) = B.x.(i) + 3. * B0 * R.x.(i) * R.z.(i) / rmag5
    B.y.(i) = B.y.(i) + 3. * B0 * R.y.(i) * R.z.(i) / rmag5
    B.z.(i) = B.z.(i) + $ 
      B0 * ( 2.*R.z.(i)*R.z.(i) - R.x.(i)*R.x.(i) - R.y.(i)*R.y.(i) ) / rmag5
  endfor

  RETURN, B
  END
