
  FUNCTION BHARRIS, R, normal=NORMAL, lscale=LSCALE, noisel=NOISEL
; ===============================================================
; BHARRIS simulates magnetic field measurements in Harris sheet. 
;
; R is expected to be a structure with 3 entries (.x .y .z) 
; and 4 sub-entries (.c1 .c2 .c3 .c4).  
; Output B is of the same structure.  
; Keyword NORMAL specifies Harris sheet normal 
; (string; DEFAULT:'z').  
;
; Keyword LSCALE specifies length scale of Harris sheet 
; (float, default: 1.).   
;
; Keyword NOISEL specifies noise level 
; (float, default: 0.)   
; 
; JoV, 4/01. 
; Modification history: 
; * 12/03, JoV: keyword LSCALE added. 
; ===============================================================

  if not keyword_set(NORMAL) then NORMAL='z'
  if not keyword_set(LSCALE) then LSCALE=1.
  if not keyword_set(NOISEL) then NOISEL=0.
  B = R

; Harris sheet parameters
; -----------------------
  B0=1.      ;... scale factor 
  L=LSCALE   ;... length scale 

; Mimic random fluctuations.
; --------------------------
  nr = n_elements(R.x.c1)
  for i=0,3 do for j=0,2 do B.(j).(i) = NOISEL*B0*randomn(seed,nr)

; Harris sheet magnetic field
; ---------------------------
  case NORMAL of 
   'z': begin 
        for i=0,3 do B.x.(i) = B.x.(i) + B0 * TANH( R.z.(i)/L )
        end
   'x': begin 
        for i=0,3 do B.y.(i) = B.y.(i) + B0 * TANH( R.x.(i)/L )
        end  
   'y': begin 
        for i=0,3 do B.z.(i) = B.z.(i) + B0 * TANH( R.y.(i)/L )
        end  
  else: begin
        print, 'FUNCTION BHARRIS: non-supported value of NORMAL'
        STOP
        end
  endcase

  RETURN, B
  END
