
  FUNCTION BRADIAL2, R, noisel=NOISEL
; ===============================================================
; BRADIAL2 simulates B field measurements in RADIALly converging 
; model magnetic field (2 dim) to test effect of field line 
; convergence on gradient estimation.
;
; Model field is an axially symmetric radial field 
; (should be OK if z-axis is not inside cluster tetrahedron). 
;
; R is expected to be a structure with 3 entries (.x .y .z) 
; and 4 sub-entries (.c1 .c2 .c3 .c4).  
; Output B is of the same structure.  
;
; Keyword NOISEL specifies noise level 
; (float, default: 0.)   
; 
; JoV, PeD, 2/04. 
; Modification history: 
;  
; ===============================================================

  if not keyword_set(NOISEL) then NOISEL=0.
  B = R

; Field parameters.
; -----------------
  B0=1.      ;... scale factor 

; Mimic random fluctuations.
; --------------------------
  nr = n_elements(R.x.c1)
  for i=0,3 do for j=0,2 do B.(j).(i) = NOISEL*B0*randomn(seed,nr)

; Radial magnetic field.
; ----------------------
  for i=0,3 do begin
    rmag2 = (R.x.(i))^2 + (R.y.(i))^2 
    B.x.(i) = B.x.(i) - B0 * R.x.(i) / rmag2
    B.y.(i) = B.y.(i) - B0 * R.y.(i) / rmag2
  endfor

  RETURN, B
  END
