
; ======================================================================
; file plot-pdfest.pro : driver for function PDFEST (pdf estimation) 
; - read data file with average sunspot numbers R and 
;   geomagnetic indices Kp and Dst,   
; - normalize data (to zero mean and unit variance),  
; - compute pdf estimates and plot.
;
; JoV, 7/03. 
; ======================================================================

; Define the window width and type HERE!
; --------------------------------------
  WINTYPE = 'gaussian'
  WINWIDTH = 0.1
  PSFILE = 'pdfest_01.ps'
  
; Read data from file rkp10dst27.dat .
; ------------------------------------
  nrec=513
  year=intarr(nrec) & day=intarr(nrec) & rotnum=lonarr(nrec) 
  r=intarr(nrec) & kp10=intarr(nrec) & dst=lonarr(nrec)
  OPENR, lun, 'rkp10dst27.dat', /get_lun
  for i=0,nrec-1 do begin 
    a=0 & b=0 & c=0L & d=0 & e=0 & f=0L
    readf, lun, a, b, c, d, e, f
    year[i]   = a
    day[i]    = b
    rotnum[i] = c
    r[i]      = d
    kp10[i]   = e
    dst[i]    = f
  endfor
  CLOSE, lun

; Normalize data to zero mean and unit variance. 
; ----------------------------------------------
  rnorm = ( r - mean(r) ) / stddev(r)
  knorm = ( kp10 - mean(kp10) ) / stddev(kp10)
  dnorm = ( dst - mean(dst) ) / stddev(dst)

; Generate normally distributed random number sequence for comparison.
; --------------------------------------------------------------------
  znorm = randomn(seed,nrec)

; Set plot parameters.
; --------------------
  olddevicename = !d.name
  set_plot, 'ps'
  device, xoff=2.5, yoff=1, xs=15, ys=12, filename=PSFILE
  !p.thick=2 & !x.thick=2 & !y.thick=2 & !p.charthick=2
  !p.multi = [0,2,2]
  myxrange = [-5.,5.]  
  myyrange = [0.,0.6]
  u = -5. + findgen(201)/20.

; Compute pdf estimates and plot. 
; -------------------------------
; ... sunspot numbers ...
  plot, u, PDFEST(u,rnorm,wintype=WINTYPE,winwidth=WINWIDTH),  $
        xrange=myxrange, yrange=myyrange, xstyle=1, ystyle=1,  $
        title='!6Sunspot number R', xtitle='!6R[norm]',        $
        ytitle='!6pdf(R[norm])'
; ... Kp10 ...
  plot, u, PDFEST(u,knorm,wintype=WINTYPE,winwidth=WINWIDTH),  $
        xrange=myxrange, yrange=myyrange, xstyle=1, ystyle=1,  $
        title='!6Index Kp10', xtitle='!6Kp10[norm]',           $
        ytitle='!6pdf(Kp10[norm])'
; ... Dst index ...
  plot, u, PDFEST(u,dnorm,wintype=WINTYPE,winwidth=WINWIDTH),  $
        xrange=myxrange, yrange=myyrange, xstyle=1, ystyle=1,  $
        title='!6Index Dst', xtitle='!6Dst[norm]',             $
        ytitle='!6pdf(Dst[norm])'
; ... random number sequence ...
  plot, u, PDFEST(u,znorm,wintype=WINTYPE,winwidth=WINWIDTH),  $
        xrange=myxrange, yrange=myyrange, xstyle=1, ystyle=1,  $
        title='!6Random numbers Z', xtitle='!6Z[norm]',        $
        ytitle='!6pdf(Z[norm])'

; Close file and reset plot parameters. 
; -------------------------------------
  device, /close
  set_plot, olddevicename

; All done. 
; ---------
  END 
