
  PRO ADD_OFFSETS, B
; ==================================================================
; Read offsets from file 'offsets.sav' and apply offset correction. 
; 
; Input/output variable: 
;   B  :  Magnetic field data (structure of type CLVECTOR). 
;  
; Variables read from file 'offsets.sav': 
;   offsets      :  Values to be added to magnetic field data. 
;   SPINAXESONLY :  If =1, then correction (was calculated for and) 
;                   is applied only to spin axes components. 
;   SPINAXES     :  Contains spin axes if SPINAXESONLY=1. 
;   OFFSETS_EXPL :  If set, offsets were calculated by explicit 
;                   method. 
;   OFFSETS_CRIT :  Offset calculation criterion. 
; The file 'offsets.sav' is expected to be generated in CDAT. 
;
; JoV, 5/01
; Modification history: 
;   4/03, JoV (version 0.5): 
;     * Documentation update, no substantial change.  
; ==================================================================

  restore, 'offsets.sav'

  if SPINAXESONLY then begin 
    for j=0,2 do for i=0,3 do    $
       b.(j).(i) = b.(j).(i) + offsets.(i)*SPINAXES.(j).(i)
    print, 'Offset correction of spin axes components:'     
  endif else begin 
    for j=0,2 do for i=0,3 do b.(j).(i) = b.(j).(i) + offsets.(j).(i)
    print, 'Offset correction of all components:' 
  endelse

  if OFFSETS_EXPL then print, '--> calculated by explicit method,' 

  case strlowcase(OFFSETS_CRIT) of 
    'divb' :  print, '--> based on divB criterion. '
    'gradb':  print, '--> based on gradB criterion '
    else   :  print, '--> unsupported OFFSETS_CRIT ?'
  endcase

  END


