
  FUNCTION CONVERT_TIME, IGM_STRING, to_hours=TO_HOURS, $
                         to_seconds=TO_SECONDS
; =====================================================================
; converts IGM date/time string into hours or seconds 
; since 1 Jan 1970, 00:00:00
; 
; Default IGM_STRING: '1970-01-01T00:00:00.00Z'
; 
; 6/01, JoV.  Modified from tstr2sec (M.Stellmacher, K.Schweda).  
; =====================================================================

; Check keyword settings.
; -----------------------
  time_factor=1.D  
  if keyword_set(TO_HOURS) then begin 
     time_factor=3600.D
     if keyword_set(TO_SECONDS) then begin
        print, '*** Error in FUNCTION CONVERT_TIME:'
        print, '*** Both keywords TO_SECONDS and TO_HOURS are set.'
        print, '*** TO_SECONDS will be used.'
        time_factor=1.D
     endif
  endif

; Some useful variables.
; ----------------------
  year     = 70
  month    = 0L
  day      = 0L
  hour     = 0L
  minute   = 0L
  second   = 0D
; ... total number of days for all (!) in previous months
  day_per_month      = [0,31,59,90,120,151,181,212,243,273,304,334]
  day_per_month_leap = [0,31,60,91,121,152,182,213,244,274,305,335]

; Split string into parts.
; ------------------------
; ... eliminate blanks  
  IGM_STRING = strcompress(IGM_STRING,/remove_all)
; ... search string for deliminators T,Z,- and :
  find_T     = strpos(IGM_STRING,'T')
  find_Z     = strpos(IGM_STRING,'Z')
  find_date1 = strpos(IGM_STRING,'-')
  find_date2 = strpos(IGM_STRING,'-',find_date1+1)
  find_time1 = strpos(IGM_STRING,':')
  find_time2 = strpos(IGM_STRING,':',find_time1+1)

; Assign year, month, day.
; ------------------------
; ... read date if set (only if deliminator 'T' is set)
  if (find_T ne -1) then begin 
; ..... read last one or two integers of year-string
    if (find_date1 eq 1) then year = long( strmid(IGM_STRING,find_date1-2,1) )
    if (find_date1 ge 2) then year = long( strmid(IGM_STRING,find_date1-2,2) )
; ..... read month and day between deliminators
    month = long( strmid(IGM_STRING,find_date1+1,find_date2-find_date1-1) )
    day = long( strmid(IGM_STRING,find_date2+1,find_T-find_date2-1) )
  endif
; ... transform dates after 1999 into the year 20xx
  if (year lt 70) then year = year + 100L
; ... set defaults if no values are given (Jan-01)
  if (month eq 0) then month = 1
  if (day eq 0) then day = 1

; Assign hour, minute, second.
; ----------------------------
  hour  = long(strmid(IGM_STRING,find_T+1,find_time1-find_T-1))
  minute = long(strmid(IGM_STRING,find_time1+1,find_time2-find_time1-1))
; ... read seconds with or without end-deliminator 'Z'
  if (find_Z ne -1) then begin
     second = double( strmid( IGM_STRING, find_time2+1, find_Z-find_time2-1) )
  endif else begin 
     second = double( strmid( IGM_STRING, find_time2+1, $
                              strlen(IGM_STRING)-find_time2-1) )
  endelse

; Calculate day-of-year, taking leap years into account. 
; ------------------------------------------------------
  if ( (year mod 4) eq 0) then        $
     doy = long( day_per_month_leap(month-1) + day )
  if ( (year mod 4) ne 0) then        $
     doy = long( day_per_month(month-1) + day )

; Calculate seconds since Jan-01 1970, 00:00:00.000
; -------------------------------------------------
; ... note that 1968 was a leap year, this leads to 1969 being a 
; ... second reference and therewith to the negative offset 
  sectime = double(-31536000.+           $ ; seconds in 1969 (ref. for leap)
             (year-69.D)*365.D*86400L+   $ ; sec of years
             long((year-69.)/4.)*86400L+ $ ; extra sec for leap years
             (doy-1L)*86400L+            $ ; seconds of current year
             hour*3600L+                 $ ; seconds of hour
             minute*60L+                 $ ; seconds of minute
             second)

; Return seconds or hours since 1 Jan 1970 as double.
; ---------------------------------------------------
  RETURN, sectime/time_factor

  END


