
  FUNCTION OFFSETS_ALL, K, B, criterion=CRITERION, explicit=EXPLICIT  
; =====================================================================
; Calculate spin axes offsets for all four Cluster FGM's 
; based on CRITERION: 
; = 'divB'  --> minimize <|divB|^2> 
; = 'gradB' --> minimize <|gradB|^2>
;
; K and B are supposed to be arrays of structures of type CLVECTOR.  
; 
; A single structure of type CLVECTOR is returned, representing
; the offsets to be added to the FGM components. 
; 
; JoV, 5/01
; Modification history: 
;   4/03, JoV (with cdat version 0.51)
;     * Bug fix: correct computation of k2 
;     * Bug fix: ks.(j).(i) replaced by K.(j).(i) 
; =====================================================================

; Check keyword settings. 
; -----------------------
  if not keyword_set(CRITERION) then CRITERION='divB'

; Compute offsets.
; ----------------
   offsets = {CLVECTOR} 
   case CRITERION of 
    'divB' : begin 
             divB = DIV_VECTOR( K , B )
             if EXPLICIT then begin 
                 k2cls = SUMCOMP(K,K) 
                 k2 = k2cls.(0) + k2cls.(1) + k2cls.(2) + k2cls.(3) 
                 for j=0,2 do for i=0,3 do  $
                    offsets.(j).(i) = - mean( (divB/k2)*K.(j).(i) ) 
             endif else begin 
                 kk = fltarr(12,12)
                 kkb = fltarr(12) 
                 for j=0,2 do for i=0,3 do begin 
                   kkb[i*3+j] = mean( divB*K.(j).(i) )
                    for jj=0,2 do for ii=0,3 do  $
                       kk[i*3+j,ii*3+jj] = mean( K.(j).(i)*K.(jj).(ii) )
                 endfor
                 SVDC, kk, w, u, v
                 print, ' '
                 print, 'Singular Values: ', w
                 print, 'Type in index where SVs should be zeroed: '
                 read, ii
                 for i=ii,11 do w[i]=0.
                 boff = SVSOL( u, w, v, -kkb )
                 for j=0,2 do for i=0,3 do offsets.(j).(i) = boff[i*3+j]
             endelse 
             end
    'gradB' : print, 'Offset criterion gradB not supported yet.'
    else    : begin 
              print, 'Non-supported CRITERION in function OFFSET_ALL.' 
              STOP
              end
  endcase 

  RETURN, offsets
  END

