
  FUNCTION OFFSETS_SPIN, K, B, SPINAXES,           $
         criterion=CRITERION, explicit=EXPLICIT  
; ==============================================================
; Calculate spin axes offsets for all four Cluster FGM's 
; based on CRITERION: 
; = 'divB'  --> minimize <|divB|^2> 
; = 'gradB' --> minimize <|gradB|^2>
;
; K, B, and SPINAXES are supposed to be arrays of structures 
; of type CLVECTOR.  
; 
; A single structure of type CLSCALAR is returned, representing
; the offsets to be added to the spin axes components. 
; 
; JoV, 5/01
; ==============================================================

; Check keyword settings. 
; -----------------------
  if not keyword_set(CRITERION) then CRITERION='divB'

; Compute offsets.
; ----------------
   offsets = {CLSCALAR} 
   case CRITERION of 
    'divB' : begin 
             divB = DIV_VECTOR( K , B )
             ks = SUMCOMP( K , SPINAXES )
             if EXPLICIT then begin 
                 ks2 = SUMSAT( ks , ks )
                 for i=0,3 do offsets.(i) = - mean( (divB/ks2)*ks.(i) ) 
             endif else begin 
                 kk = fltarr(4,4)
                 kkb = fltarr(4) 
                 for i=0,3 do begin 
                   kkb[i] = mean( divB*ks.(i) )
                    for j=0,3 do kk[i,j] = mean( ks.(i)*ks.(j) )
                 endfor
                 SVDC, kk, w, u, v
                 print, ' '
                 print, 'Singular Values: ', w
                 print, 'Type in index where SVs should be zeroed: '
                 read, ii
                 for i=ii,3 do w[i]=0.
                 boff = SVSOL( u, w, v, -kkb )
                 for i=0,3 do offsets.(i) = boff[i]
             endelse 
             end
    'gradB' : print, 'Offset criterion gradB not supported yet.'
    else    : begin 
              print, 'Non-supported CRITERION in function OFFSET_SPIN.' 
              STOP
              end
  endcase 

  RETURN, offsets
  END

