
  PRO PLOT3X3, T, M, varname=VARNAME, infostring=INFOSTRING, $
               xtstring=XTSTRING, ytstring=YTSTRING,         $
               psfile=PSFILE, conv_factor=CONV_FACTOR
; ===================================================================
; PLOT elements of structure M (type: XYZMATRIX) as 3x3 time series. 
;
; Usage: only inside routine cdat.
; 
; Input variables: 
;   T  :  Hour of day as floating point array. 
;   M  :  Structure of type XYZMATRIX. 
;
; Keywords: 
;   VARNAME    :  Variable name of M (printed with INFOSTRING). 
;   INFOSTRING :  String to be written on lower right edge. 
;   XTSTRING   :  x-title. 
;   YTSTRING   :  y-title. 
;   PSFILE     :  If set, then graphics output is to file PSFILE. 
;                 Default graphics output is to screen ('X'). 
;
; JoV, 5/01
; Modification history:
;   4/03: 
;     * Landscape instead of portrait. 
;     * UT on x-axis in hh:mm.
;     * Documentation update. 
;     * Reset of all plot parameters. 
; ===================================================================

; Check keyword settings.
; -----------------------
  if not keyword_set(XTSTRING) then XTSTRING='X'
  if not keyword_set(YTSTRING) then XTSTRING='Y'
  if not keyword_set(CONV_FACTOR) then CONV_FACTOR=1. 

; Switch to PS device if necessary.
; ---------------------------------
  !P.MULTI = [0,3,3,1,0]
  if keyword_set(PSFILE) then begin
    device_name = !D.NAME
    SET_PLOT, 'PS'
    DEVICE, xoff=3, yoff=27.5, xsize=25, ysize=15, FILENAME=PSFILE, $
            /landscape
  endif 
  default_xstyle = !X.STYLE
  !X.STYLE = 1

; Plot structure M.
; -----------------
  names1 = tag_names(M) 
  for j=0,2 do begin
    names2 = tag_names(M.(j)) 
    for i=0,2 do begin
      PLOT, T*60.D0, CONV_FACTOR*M.(j).(i),            $
            title=names1[j]+names2[i]+'-comp.',  $
            xtitle=XTSTRING, ytitle=YTSTRING, xtickformat='HHMM'
    endfor
  endfor

; Write INFOSTRING on lower right edge.
; -------------------------------------
  if keyword_set(INFOSTRING) then                              $
    if keyword_set(VARNAME) then                               $ 
      XYOUTS, 1,0, INFOSTRING+' : '+VARNAME, /normal,          $
              alignment=1, charsize=0.5                        $
    else                                                       $
      XYOUTS, 1,0, INFOSTRING, /normal, alignment=1,           $ 
              charsize=0.5 

; Switch back to X device and reset other plot parameters.
; --------------------------------------------------------
  if keyword_set(PSFILE) then begin
     DEVICE, /close
     SET_PLOT, device_name
  endif 
  !P.MULTI = 0
  !X.STYLE = default_xstyle 

  END
