
  PRO PLOT4X3, T, V, varname=VARNAME, infostring=INFOSTRING, $
               xtstring=XTSTRING, ytstring=YTSTRING,         $
               psfile=PSFILE, conv_factor=CONV_FACTOR
; ===================================================================
; PLOT elements of structure V (type: CLVECTOR) as 4x3 time series.
;
; Usage: only inside routine cdat.
; 
; Input variables: 
;   T  :  Hour of day as floating point array. 
;   V  :  Structure of type CLVECTOR. 
;
; Keywords: 
;   VARNAME    :  Variable name of V (printed with INFOSTRING).  
;   INFOSTRING :  String to be written on lower right edge. 
;   XTSTRING   :  x-title. 
;   YTSTRING   :  y-title. 
;   PSFILE     :  If set, then graphics output is to file PSFILE. 
;                 Default graphics output is to screen ('X'). 
;   CONV_FACTOR:  Conversion factor. 
;
; JoV, 5/01
; Modification history:
;   4/03: 
;     * Landscape instead of portrait. 
;     * UT on x-axis in hh:mm.
;     * Documentation update. 
;     * Keyword YNOZERO included in PLOT command. 
;     * Reset of all plot parameters. 
; ===================================================================

; Check keyword settings.
; -----------------------
  if not keyword_set(XTSTRING) then XTSTRING='X'
  if not keyword_set(YTSTRING) then XTSTRING='Y'
  if not keyword_set(CONV_FACTOR) then CONV_FACTOR=1. 

; Switch to PS device if necessary.
; ---------------------------------
  !P.MULTI = [0,4,3,1,0]
  if keyword_set(PSFILE) then begin
    device_name = !D.NAME
    SET_PLOT, 'PS'
    DEVICE, xoff=3, yoff=27.5, xsize=25, ysize=15, FILENAME=PSFILE, $
            /LANDSCAPE
  endif 

; Plot structure V.
; -----------------
  names1 = tag_names(V) 
  for j=0,2 do begin
    names2 = tag_names(V.(j)) 
    for i=0,3 do begin
      PLOT, T*60.D0, CONV_FACTOR*V.(j).(i),                       $
            title=names2[i]+', '+names1[j]+'-comp.',              $
            xtitle=XTSTRING, ytitle=YTSTRING, xtickformat='hhmm', $
            /YNOZERO, xstyle=1
    endfor
  endfor

; Write INFOSTRING on lower right edge.
; -------------------------------------
  if keyword_set(INFOSTRING) then                              $
    if keyword_set(VARNAME) then                               $ 
      XYOUTS, 1,0, INFOSTRING+' : '+VARNAME, /normal,          $
              alignment=1, charsize=0.5                        $
    else                                                       $
      XYOUTS, 1,0, INFOSTRING, /normal, alignment=1,           $ 
              charsize=0.5 

; Switch back to X device and reset other plot parameters.
; --------------------------------------------------------
  if keyword_set(PSFILE) then begin
     DEVICE, /close
     SET_PLOT, device_name
  endif 
  !P.MULTI = 0

  END
