
  PRO SKIPGAPS, TIME, B, R, RBAR, DATABAD,   $ 
                TOK, BOK, ROK, RBAROK,       $
                barycentric=BARYCENTRIC, showgaps=SHOWGAPS
; ====================================================================
; SKIP data GAPS in various arrays for use in CDAT. 
;
; Input variables: 
;   TIME    :  Hour of day as floating point array. 
;   B       :  Magnetic field data as structure of type CLVECTOR.
;   R       :  Spacecraft position data as structure of type CLVECTOR.
;   RBAR    :  Cluster barycenter as structure of type XYZVECTOR. 
;   DATABAD :  Flag to indicate data quality (type CLSCALAR_BYTE). 
;
; Output variables: 
;   TOK     :  Hour of day as floating point array. 
;   BOK     :  Magnetic field data as structure of type CLVECTOR.
;   ROK     :  Spacecraft position data as structure of type CLVECTOR.
;   RBAROK  :  Cluster barycenter as structure of type XYZVECTOR. 
; Here 'bad' data values are skipped according to the information 
; provided through DATABAD.  
;
; Keywords: 
;   BARYCENTRIC :  If set, position data on output are relative 
;                  to the spacecraft cluster barycenter. 
;   SHOWGAPS    :  If set, print data gap information. 
;   
; JoV, 4/01
; Modification history: 
;   4/03, JoV (with cdat version 0.5): 
;     * Documentation update, no substantial change.  
;   4/03, JoV (with cdat version 0.52/0.62): 
;     * Bug fix: modified computation of index array ok. 
;     * Bug fix: evaluation of notok[0] instead of n_elements(notok).
; ====================================================================

  ok = where( (databad.c1 eq 0b) and (databad.c2 eq 0b) and   $
              (databad.c3 eq 0b) and (databad.c4 eq 0b) )

  tok = time[ok] & bok = b[ok] & rok = r[ok] & rbarok = rbar[ok]

  if keyword_set(BARYCENTRIC) then    $
    for j=0,2 do for i=0,3 do rok.(j).(i) = rok.(j).(i) - rbarok.(j)

  if keyword_set(SHOWGAPS) then begin 
    notok = where( databad.c1 or databad.c2 or $
                   databad.c3 or databad.c4 )
    if (notok[0] eq -1) then print, 'No data gaps.' else begin 
      print, 'Data gaps at '
      for i=0,n_elements(notok)-1 do begin 
         hh = fix( time(notok[i]) )
         mm = fix( ( time(notok[i]) - hh )*60 )
         ss = ( ( time(notok[i]) - hh )*60 - mm )*60.
         print, 'Index: ', strtrim(string(notok[i]),2), ',  UT: ',          $
             string( hh, mm, ss, format="(i2.2, ':', i2.2, ':', f5.2)" )
      endfor
    endelse
    print, ' '
  endif

  END
