
  FUNCTION REPROVEC, R, volume=VOLUME	
; ==========================================================
; REPROVEC computes the reciprocal vectors of the CLUSTER 
; tetrahedron as defined by the positions in R. 
; 
; Input variable: 
;   R : Structure of type CLVECTOR (3 entries (.x .y .z) 
;       and 4 sub-entries (.c1 .c2 .c3 .c4)) containing 
;       position data of all four CLUSTER spacecraft. 
; 
; Output variable (on return) : 
;       Structure of type CLVECTOR containing reciprocal 
;       vectors.  
; 
; Keywords: 
;   VOLUME : If set, then the (unsigned) volume of the  
;            tetrahedron is returned with the variable 
;            VOLUME. 
;
; JoV, 4/01
; Modification history: 
;   4/03, JoV (with cdat version 0.5): 
;     * Keyword volume added to parameter list. 
;     * Documentation update.  
; ==========================================================

  k = R

  x12 = R.x.c2 - R.x.c1
  y12 = R.y.c2 - R.y.c1
  z12 = R.z.c2 - R.z.c1

  x13 = R.x.c3 - R.x.c1
  y13 = R.y.c3 - R.y.c1
  z13 = R.z.c3 - R.z.c1

  x14 = R.x.c4 - R.x.c1
  y14 = R.y.c4 - R.y.c1
  z14 = R.z.c4 - R.z.c1

  x23 = R.x.c3 - R.x.c2
  y23 = R.y.c3 - R.y.c2
  z23 = R.z.c3 - R.z.c2

  x24 = R.x.c4 - R.x.c2
  y24 = R.y.c4 - R.y.c2
  z24 = R.z.c4 - R.z.c2

  x34 = R.x.c4 - R.x.c3
  y34 = R.y.c4 - R.y.c3
  z34 = R.z.c4 - R.z.c3

  k.x.c4 = y12*z13 - z12*y13
  k.y.c4 = z12*x13 - x12*z13
  k.z.c4 = x12*y13 - y12*x13
  vol4 = x14*k.x.c4 + y14*k.y.c4 + z14*k.z.c4
  for j=0,2 do k.(j).c4 = k.(j).c4/vol4

  k.x.c1 = y23*z24 - z23*y24
  k.y.c1 = z23*x24 - x23*z24
  k.z.c1 = x23*y24 - y23*x24
  vol1 = - ( x12*k.x.c1 + y12*k.y.c1 + z12*k.z.c1 )
  for j=0,2 do k.(j).c1 = k.(j).c1/vol1

  k.x.c2 = - ( y34*z13 - z34*y13 )
  k.y.c2 = - ( z34*x13 - x34*z13 )
  k.z.c2 = - ( x34*y13 - y34*x13 )
  vol2 = - ( x23*k.x.c2 + y23*k.y.c2 + z23*k.z.c2 )
  for j=0,2 do k.(j).c2 = k.(j).c2/vol2

  k.x.c3 = y14*z24 - z14*y24
  k.y.c3 = z14*x24 - x14*z24
  k.z.c3 = x14*y24 - y14*x24
  vol3 = - ( x34*k.x.c3 + y34*k.y.c3 + z34*k.z.c3 )
  for j=0,2 do k.(j).c3 = k.(j).c3/vol3

  if keyword_set(VOLUME) then $ 
     VOLUME = 0.25*( abs(vol4) + abs(vol1) + abs(vol2) + abs(vol3) ) 

  return, k
  end



